@@ -18,7 +18,10 @@ class RunCase(TestCase):
             self.skipTest('skip')
         if Var.re_start:
             if Var.driver != 'selenium':
-                DriverBaseApp.launch_app(None)
+                if Var.not_first_case:
+                    DriverBaseApp.launch_app(None)
+                else:
+                    Var.not_first_case = True
             else:
                 DriverBaseWeb.createSession()
 
