@@ -37,7 +37,9 @@ class ServerUtilsApp(object):
         try:
             log_info('Start the server...')
             self.stop_server()
-            if self.driver == 'appium':
+            if self.driver == 'minium':
+                ""
+            elif self.driver == 'appium':
                 bp_port = self._get_device_port()
                 wda_port = self._get_device_port()
                 udid = self.desired_capabilities['udid']
